# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.conf.global_settings import TEMPLATE_CONTEXT_PROCESSORS

SECRET_KEY = 'iz@*(xuwo+a2a2r+jb1p8-ap8hic1_l(h$vj(mr_v!d6%ijr1n'

DEBUG = True

TEMPLATE_DEBUG = True


ALLOWED_HOSTS = []

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    #     'django.template.loaders.eggs.Loader',
)

# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_reamaze',)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.doc.XViewMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.middleware.locale.LocaleMiddleware',)

TEMPLATE_CONTEXT_PROCESSORS += (
    'django.core.context_processors.request',)


DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}

STATIC_URL = '/static/'


REAMAZE_SECRET_KEY = b"125acdef1425da15af6cd8870a878c878c48cc8"
REAMAZE_JS_URL = "//URL/reamaze.js"
REAMAZE_ACCOUNT = "ACCOUNT_NAME"
REAMAZE_CHANNEL = "CHANNEL_NAME"
REAMAZE_OK_FOR_ANONYMOUS = True
REAMAZE_PREFIX_USER_ID = None



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.template import Template, Context
from django.contrib.auth.models import AnonymousUser
from django.test import TestCase
from django.test.client import RequestFactory
from django.conf import settings

import django
if django.get_version().startswith("1.4"):
    from django.contrib.auth.models import User
else:
    from django.contrib.auth import get_user_model


class ReamazeTagTest(TestCase):

    TEMPLATE = Template("{% load reamaze %} {% add_reamaze_script %}")

    def setUp(self):
        self.factory = RequestFactory()
        self.request = self.factory.get('/dummyview')
        self.request.session = {}

    def test_reamaze_anonymous_not_display(self):
        settings.REAMAZE_OK_FOR_ANONYMOUS = False
        self.request.user = AnonymousUser()
        rendered = self.TEMPLATE.render(Context({'request': self.request,
                                                 'totoa': 'TRTR'}))
        self.assertNotIn("reamaze.js", rendered)

    def test_reamaze_anonymous_display(self):
        settings.REAMAZE_OK_FOR_ANONYMOUS = True
        self.request.user = AnonymousUser()
        self.request.META['HTTP_USER_AGENT'] = 'Firefox'
        self.request.META['HTTP_REFERER'] = 'http_referer'
        rendered = self.TEMPLATE.render(Context({'request': self.request}))
        self.assertIn("reamaze.js", rendered)
        self.assertNotIn("authkey", rendered)

    def test_reamaze_user_display(self):
        if django.get_version().startswith("1.4"):
            self.user = User.objects.create(username='realuser',
                                            email='email@email.com')
        else:
            self.user = get_user_model().objects.create(username='realuser',
                                                        email='email@email.com')

        self.request.user = self.user
        self.request.META['HTTP_USER_AGENT'] = 'Firefox'
        self.request.META['HTTP_REFERER'] = 'http_referer'
        rendered = self.TEMPLATE.render(Context({'request': self.request}))
        self.assertIn("reamaze.js", rendered)
        self.assertIn("authkey", rendered)
        self.assertIn("_support['name'] = 'realuser';", rendered)

    def test_reamaze_user_with_prefix_display(self):
        if django.get_version().startswith("1.4"):
            self.user = User.objects.create(username='realuser',
                                            email='email@email.com')
        else:
            self.user = get_user_model().objects.create(username='realuser',
                                                        email='email@email.com')

        settings.REAMAZE_PREFIX_USER_ID = 'prefix_id'
        self.request.user = self.user

        self.request.META['HTTP_USER_AGENT'] = 'Firefox'
        self.request.META['HTTP_REFERER'] = 'http_referer'
        rendered = self.TEMPLATE.render(Context({'request': self.request}))
        self.assertIn("_support['id'] = '%s%s'" % (settings.REAMAZE_PREFIX_USER_ID, str(self.user.pk)), rendered)
        self.assertIn("authkey", rendered)
        self.assertIn("_support['name'] = 'realuser';", rendered)
        settings.REAMAZE_PREFIX_USER_ID = None

    def test_reamaze_user_agent_and_no_referer(self):
        if django.get_version().startswith("1.4"):
            self.user = User.objects.create(username='realuser',
                                            email='email@email.com')
        else:
            self.user = get_user_model().objects.create(username='realuser',
                                                        email='email@email.com')
        self.request.user = self.user
        self.request.META['HTTP_USER_AGENT'] = 'Firefox'
        rendered = self.TEMPLATE.render(Context({'request': self.request}))
        self.assertIn("reamaze.js", rendered)
        self.assertIn("authkey", rendered)
        self.assertIn("""value: "Firefox""""", rendered)
        self.assertIn("_support['name'] = 'realuser';", rendered)

    def test_reamaze_not_with_channel(self):
        settings.REAMAZE_OK_FOR_ANONYMOUS = True
        settings.REAMAZE_CHANNEL = None
        self.request.user = AnonymousUser()
        self.request.META['HTTP_USER_AGENT'] = 'Firefox'
        self.request.META['HTTP_REFERER'] = 'http_referer'
        rendered = self.TEMPLATE.render(Context({'request': self.request}))
        self.assertIn("reamaze.js", rendered)
        self.assertNotIn("channel", rendered)

    def test_reamaze_with_channel(self):
        settings.REAMAZE_OK_FOR_ANONYMOUS = True
        self.request.user = AnonymousUser()
        self.request.META['HTTP_USER_AGENT'] = 'Firefox'
        self.request.META['HTTP_REFERER'] = 'http_referer'
        rendered = self.TEMPLATE.render(Context({'request': self.request}))
        self.assertIn("reamaze.js", rendered)
        self.assertNotIn("mailbox: 'CHANNEL_NAME'", rendered)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.utils import six
from django.conf import settings
from django.template import Library
register = Library()


@register.inclusion_tag('django_reamaze/templatetags/reamaze.html', takes_context=True)
def add_reamaze_script(context):
    import hmac
    import hashlib
    try:
        anonymous_mode = getattr(settings, 'REAMAZE_OK_FOR_ANONYMOUS', False)
        prefix_for_user_id = getattr(settings, 'REAMAZE_PREFIX_USER_ID', None)
        request = context['request']
        reamaze_context = {'display_reamaze': False, 'reamaze_auth_key': None}
        user_id = reamaze_context["user_id"] = request.user.id
        if prefix_for_user_id:
            user_id = prefix_for_user_id + str(request.user.id)
        reamaze_context["user_id"] = user_id
        if request.user.is_authenticated() or anonymous_mode:
            reamaze_context.update({'display_reamaze': True,
                                    'reamaze_js_url': getattr(settings, 'REAMAZE_JS_URL', ""),
                                    'reamaze_account': getattr(settings, 'REAMAZE_ACCOUNT', ""),
                                    'user_agent': request.META['HTTP_USER_AGENT'],
                                    'http_referer': request.META.get('HTTP_REFERER', ""),
                                    'reamaze_channel': getattr(settings, 'REAMAZE_CHANNEL', None)})

        if request.user.is_authenticated():
            reamaze_secret_key = getattr(settings, 'REAMAZE_SECRET_KEY', b"")
            reamaze_auth_key = hmac.new(reamaze_secret_key,
                                        six.b(str(user_id)) + b":" + six.b(request.user.email),
                                        hashlib.sha256).hexdigest()
            reamaze_context['reamaze_auth_key'] = reamaze_auth_key

        context.update(reamaze_context)
        return context
    except KeyError:
        return context
